pub struct CreateOrca {
pub bid_denom: Denom,
pub bid_threshold: Uint128,
pub max_slot: u8,
pub premium_rate_per_slot: Decimal,
pub waiting_period: u64,
}Fields
bid_denom: DenomThe raise token, that the price is quoted in
bid_threshold: Uint128The threshold under which bids are automatically activated when placed
max_slot: u8The total number of pools in this queue
The incremental discount offered per-pool
waiting_period: u64The amount of time in seconds that a bid must wait until it can be activated