pub struct CreateSale {
pub title: String,
pub description: String,
pub url: String,
pub beneficiary: Addr,
pub price: Decimal,
pub opens: Timestamp,
pub closes: Timestamp,
}Fields
title: Stringdescription: Stringurl: Stringbeneficiary: AddrThe address that the raise will be sent to
price: DecimalBase price of the token at sale
opens: Timestampcloses: TimestampThe time after which the sale can be executed